import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

public class FormMapWithSetWarships extends JFrame{
    private JPanel mainPanel;
    private JPanel PictureBox;
    private JPanel GroupBoxTools;
    private JComboBox СomboBoxSelectorMap;
    private JButton ButtonAddWarship;
    private JButton ButtonRemoveWarship;
    private JButton ButtonShowStorage;
    private JButton ButtonShowOnMap;
    private JTextField TextBoxPosition;
    private JButton ButtonRight;
    private JButton ButtonUp;
    private JButton ButtonDown;
    private JButton ButtonLeft;
    private Image bufferedImage;
    private MapWithSetWarshipsGeneric<DrawingObjectWarship, AbstractMap> _mapWarshipsCollectionGeneric;

    public FormMapWithSetWarships(){
        InitializeComponent();


    }

    public void InitializeComponent(){
        setContentPane(mainPanel);
        setTitle("Warship");
        setSize(1000, 685);
        setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        setVisible(true);

        Icon iconUp = new ImageIcon("src\\Images\\ArrowUp.jpg");
        ButtonUp.setIcon(iconUp);
        Icon iconDown = new ImageIcon("src\\Images\\ArrowDown.jpg");
        ButtonDown.setIcon(iconDown);
        Icon iconLeft = new ImageIcon("src\\Images\\ArrowLeft.jpg");
        ButtonLeft.setIcon(iconLeft);
        Icon iconRight = new ImageIcon("src\\Images\\ArrowRight.jpg");
        ButtonRight.setIcon(iconRight);

        СomboBoxSelectorMap.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                AbstractMap map = null;
                switch ((String) СomboBoxSelectorMap.getSelectedItem()){
                    case "Простая карта":
                        map = new SimpleMap();
                        break;
                    case "Преграды-линии":
                        map = new LineMap();
                        break;
                }
                if( map != null){
                    _mapWarshipsCollectionGeneric = new MapWithSetWarshipsGeneric<DrawingObjectWarship, AbstractMap>(
                            PictureBox.getWidth(), PictureBox.getHeight(), map);
                }
                else
                {
                    _mapWarshipsCollectionGeneric = null;
                }
            }
        });

        ButtonAddWarship.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if(_mapWarshipsCollectionGeneric == null){
                    return;
                }
                FormWarship form = new FormWarship();
                form.setSize(1200,700);
                form.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
                form.setVisible(true);
                form.addWindowListener(new WindowAdapter() {
                    @Override
                    public void windowDeactivated(WindowEvent e) {
                        DrawingObjectWarship warship = new DrawingObjectWarship(form.getSelectedCar());
                        if (_mapWarshipsCollectionGeneric.add(warship) > 0)
                        {
                            if (form.DialogResult)
                                JOptionPane.showMessageDialog(null, "Объект добавлен");
                            bufferedImage = _mapWarshipsCollectionGeneric.ShowSet();
                            repaint();
                        }
                        else
                        {
                            JOptionPane.showMessageDialog(null, "Не удалось добавить объект");
                        }
                    }
                });
            }
        });

        ButtonRemoveWarship.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                String text = TextBoxPosition.getText();
                if (text == null || _mapWarshipsCollectionGeneric == null || text.isEmpty())
                {
                    return;
                }
                int result = JOptionPane.showConfirmDialog(
                        null,
                        "Удалить объект?",
                        "Удаление",
                        JOptionPane.YES_NO_CANCEL_OPTION);
                if (result == JOptionPane.NO_OPTION)
                {
                    return;
                }
                int pos = Integer.parseInt(text);
                if (_mapWarshipsCollectionGeneric.remove(pos) != null)
                {
                    JOptionPane.showMessageDialog(null,"Объект удален","Успех",JOptionPane.INFORMATION_MESSAGE);
                    bufferedImage = _mapWarshipsCollectionGeneric.ShowSet();
                    repaint();
                }
                else
                {
                    JOptionPane.showMessageDialog(null,"Не удалось удалить объект","Ошибка",JOptionPane.INFORMATION_MESSAGE);
                }
            }
        });

        ButtonShowStorage.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if(_mapWarshipsCollectionGeneric == null)
                {
                    return;
                }
                bufferedImage = _mapWarshipsCollectionGeneric.ShowSet();
                repaint();
            }
        });

        ButtonShowOnMap.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (_mapWarshipsCollectionGeneric == null)
                {
                    return;
                }
                bufferedImage = _mapWarshipsCollectionGeneric.ShowOnMap();
                repaint();
            }
        });
    }
}
